@@ -186,8 +186,6 @@ private:
   // FmFileInfo* currentFileInfo_; // info of the current file, can be NULL
   bool imageModified_; // the current image is modified by rotation, flip, or others and needs to be saved
 
-  bool startMaximized_;
-
   // folder browsing
   std::shared_ptr<Fm::Folder> folder_;
   Fm::FilePath folderPath_;
@@ -213,6 +211,8 @@ private:
   bool showFullScreen_;
 
   QMap<int, QShortcut*> hardCodedShortcuts_; // may be overridden by custom shortcuts
+
+  qreal lastPixRatio_;
 };
 
 }
