@@ -6,17 +6,17 @@
     <message>
         <location filename="../shortcuts.ui" line="14"/>
         <source>Hidden Shortcuts</source>
-        <translation>隱藏的快捷鍵</translation>
+        <translation>隱藏的快速鍵</translation>
     </message>
     <message>
         <location filename="../shortcuts.ui" line="20"/>
         <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
-        <translation>這些固定的快捷鍵，當在「偏好設定」→ 「快捷鍵」內被指定給其他動作時，將會被覆蓋。</translation>
+        <translation>這些固定的快速鍵將會被覆蓋，如果在 偏好設定 → 快速鍵 中被指定其他動作時。</translation>
     </message>
     <message>
         <location filename="../shortcuts.ui" line="34"/>
         <source>Shortcut</source>
-        <translation>快捷鍵</translation>
+        <translation>快速鍵</translation>
     </message>
     <message>
         <location filename="../shortcuts.ui" line="39"/>
@@ -89,27 +89,27 @@
 <context>
     <name>LxImage::Application</name>
     <message>
-        <location filename="../application.cpp" line="93"/>
+        <location filename="../application.cpp" line="96"/>
         <source>Start in fullscreen (can be useful with tiling window managers)</source>
-        <translation>以全螢幕模式啟動（在圖塊式視窗管理器下會比較好用）</translation>
+        <translation>以全螢幕啟動 (在平鋪視窗管理器下會很好用)</translation>
     </message>
     <message>
-        <location filename="../application.cpp" line="101"/>
+        <location filename="../application.cpp" line="104"/>
         <source>Take a screenshot (deprecated, please use screengrab instead)</source>
         <translation>截圖（已棄用，建議使用 screengrab）</translation>
     </message>
     <message>
-        <location filename="../application.cpp" line="110"/>
+        <location filename="../application.cpp" line="113"/>
         <source>DIR</source>
         <translation>條</translation>
     </message>
     <message>
-        <location filename="../application.cpp" line="110"/>
+        <location filename="../application.cpp" line="113"/>
         <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
-        <translation>截圖並直接將其存到資料夾（已棄用，建議使用 screengrab）</translation>
+        <translation>擷圖並直接將其存到目錄（已棄用，建議使用 screengrab）</translation>
     </message>
     <message>
-        <location filename="../application.cpp" line="116"/>
+        <location filename="../application.cpp" line="119"/>
         <source>[FILE1, FILE2,...]</source>
         <translation>[檔案1、檔案2...]</translation>
     </message>
@@ -119,7 +119,7 @@
     <message>
         <location filename="../upload/imgbbupload.cpp" line="44"/>
         <source>unknown error response</source>
-        <translation>未知的錯誤回應</translation>
+        <translation>不明錯誤回應</translation>
     </message>
 </context>
 <context>
@@ -127,89 +127,89 @@
     <message>
         <location filename="../upload/imgurupload.cpp" line="47"/>
         <source>unknown error response</source>
-        <translation>未知的錯誤回應</translation>
+        <translation>不明錯誤回應</translation>
     </message>
 </context>
 <context>
     <name>LxImage::MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="277"/>
+        <location filename="../mainwindow.cpp" line="296"/>
         <source>About</source>
         <translation>關於</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="279"/>
+        <location filename="../mainwindow.cpp" line="298"/>
         <source>A simple and fast image viewer</source>
         <translation>簡單快速的圖片檢視器</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="281"/>
+        <location filename="../mainwindow.cpp" line="300"/>
         <source>Copyright (C) </source>
         <translation>版權所有 (C) </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="283"/>
+        <location filename="../mainwindow.cpp" line="302"/>
         <source>LXQt Project</source>
         <translation>LXQt 計畫</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="285"/>
+        <location filename="../mainwindow.cpp" line="304"/>
         <source>Development: </source>
         <translation>開發 </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="287"/>
+        <location filename="../mainwindow.cpp" line="306"/>
         <source>Author: </source>
         <translation>作者： </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="515"/>
+        <location filename="../mainwindow.cpp" line="536"/>
         <source>Open File</source>
         <translation>開啟檔案</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="516"/>
-        <location filename="../mainwindow.cpp" line="551"/>
+        <location filename="../mainwindow.cpp" line="537"/>
+        <location filename="../mainwindow.cpp" line="572"/>
         <source>Image files (%1)</source>
         <translation>影像檔案 (%1)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="529"/>
+        <location filename="../mainwindow.cpp" line="550"/>
         <source>Open directory</source>
-        <translation>打開資料夾</translation>
+        <translation>開啟目錄</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="550"/>
+        <location filename="../mainwindow.cpp" line="571"/>
         <source>Save File</source>
         <translation>儲存檔案</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="846"/>
+        <location filename="../mainwindow.cpp" line="869"/>
         <source>[*]%1 (Loading...) - Image Viewer</source>
-        <translation>[*]%1 (讀取中...) - 看圖軟體</translation>
+        <translation>[*]%1 (載入中...) - 看圖軟體</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="852"/>
+        <location filename="../mainwindow.cpp" line="875"/>
         <source>[*]%1 (Failed to Load) - Image Viewer</source>
-        <translation>[*]%1 (讀取失敗) - 看圖軟體</translation>
+        <translation>[*]%1 (載入失敗) - 看圖軟體</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="858"/>
+        <location filename="../mainwindow.cpp" line="881"/>
         <source>[*]%1 (%2x%3) - Image Viewer</source>
         <translation>[*]%1 (%2x%3) - 看圖軟體</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="904"/>
+        <location filename="../mainwindow.cpp" line="948"/>
         <source>[*]Image Viewer</source>
         <translation>[*]看圖軟體</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1302"/>
+        <location filename="../mainwindow.cpp" line="1347"/>
         <source>Thumbnails</source>
         <translation>縮圖</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1397"/>
+        <location filename="../mainwindow.cpp" line="1442"/>
         <source>EXIF Data</source>
         <translation>EXIF資訊</translation>
     </message>
@@ -228,8 +228,8 @@
         <location filename="../preferencesdialog.cpp" line="74"/>
         <source>Use a modifier key to clear a shortcut
 in the editing mode.</source>
-        <translation>在編輯模式下按下輔助鍵（Alt, Ctrl, Shift）
-以清除快捷鍵。</translation>
+        <translation>在編輯模式下
+使用組合修飾鍵(Alt, Ctrl, Shift)來清除快速鍵。</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.cpp" line="213"/>
@@ -249,12 +249,12 @@ in the editing mode.</source>
     <message>
         <location filename="../preferencesdialog.cpp" line="341"/>
         <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
-        <translation>&lt;b&gt;警告：重複的快捷鍵！&lt;/b&gt;</translation>
+        <translation>&lt;b&gt;警告：偵測到不明確的快速鍵！&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.cpp" line="358"/>
         <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
-        <translation>&lt;b&gt;無法處理重複的快捷鍵。&lt;/b&gt;</translation>
+        <translation>&lt;b&gt;不接受不明確的快速鍵。&lt;/b&gt;</translation>
     </message>
 </context>
 <context>
@@ -281,32 +281,32 @@ in the editing mode.</source>
 <context>
     <name>LxImage::UploadDialog</name>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="50"/>
+        <location filename="../upload/uploaddialog.cpp" line="47"/>
         <source>Imgur</source>
         <translation>Imgur</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="51"/>
+        <location filename="../upload/uploaddialog.cpp" line="48"/>
         <source>ImgBB</source>
         <translation>ImgBB</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="134"/>
+        <location filename="../upload/uploaddialog.cpp" line="136"/>
         <source>Start</source>
         <translation>開始</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="137"/>
+        <location filename="../upload/uploaddialog.cpp" line="139"/>
         <source>Stop</source>
         <translation>停止</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="140"/>
+        <location filename="../upload/uploaddialog.cpp" line="142"/>
         <source>Close</source>
         <translation>關閉</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="147"/>
+        <location filename="../upload/uploaddialog.cpp" line="149"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
@@ -404,7 +404,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="67"/>
         <source>Open &amp;With...</source>
-        <translation>以其他應用程式開啟 (&amp;W)...</translation>
+        <translation>以其他應用程式開啟(&amp;W)…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="72"/>
@@ -419,12 +419,12 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="229"/>
         <source>Hidden &amp;Shortcuts</source>
-        <translation>隱藏的快捷鍵 (&amp;S)</translation>
+        <translation>隱藏的快速鍵(&amp;S)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="238"/>
         <source>&amp;Open…</source>
-        <translation>開啟 (&amp;O)…</translation>
+        <translation>開啟(&amp;O)…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="250"/>
@@ -449,7 +449,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="364"/>
         <source>Original Size</source>
-        <translation>原始尺寸</translation>
+        <translation>原始大小</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="367"/>
@@ -519,7 +519,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="453"/>
         <source>&amp;New Window</source>
-        <translation>新視窗(&amp;N)</translation>
+        <translation>新建視窗(&amp;N)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="456"/>
@@ -539,7 +539,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="477"/>
         <source>Capture Screenshot</source>
-        <translation>拍攝螢幕快照</translation>
+        <translation>擷取螢幕畫面</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="485"/>
@@ -599,7 +599,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="562"/>
         <source>Open &amp;Directory</source>
-        <translation>打開資料夾(&amp;D)</translation>
+        <translation>開啟目錄(&amp;D)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="565"/>
@@ -634,7 +634,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="603"/>
         <source>Deselect all drawing tools</source>
-        <translation>取消選擇所有繪圖工具</translation>
+        <translation>取消選擇全部繪圖工具</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="615"/>
@@ -690,17 +690,17 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="685"/>
         <source>&amp;Main Toolbar</source>
-        <translation>主選單列 (&amp;M)</translation>
+        <translation>主選單列(&amp;M)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="688"/>
         <source>Main Toolbar</source>
-        <translation>主選單列</translation>
+        <translation>主工具列</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="696"/>
         <source>&amp;Annotations Toolbar</source>
-        <translation>註解工具列 (&amp;A)</translation>
+        <translation>註解工具列(&amp;A)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="707"/>
@@ -716,7 +716,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="721"/>
         <source>Copy Pa&amp;th</source>
-        <translation>複製路徑 (&amp;T)</translation>
+        <translation>複製路徑(&amp;T)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="724"/>
@@ -727,7 +727,7 @@ in the editing mode.</source>
         <location filename="../mainwindow.ui" line="732"/>
         <location filename="../mainwindow.ui" line="735"/>
         <source>Rename</source>
-        <translation>更改名稱</translation>
+        <translation>重新命名</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="738"/>
@@ -742,7 +742,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="755"/>
         <source>&amp;By File Name</source>
-        <translation>以檔案名稱( &amp;B)</translation>
+        <translation>依照檔案名稱(&amp;B)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="758"/>
@@ -752,7 +752,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="766"/>
         <source>By &amp;Modification Time</source>
-        <translation>以最後修改時間 (&amp;M)</translation>
+        <translation>依照最後修改時間(&amp;M)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="769"/>
@@ -762,7 +762,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="777"/>
         <source>By C&amp;reation Time</source>
-        <translation>以建立時間 (&amp;R)</translation>
+        <translation>依照建立時間(&amp;R)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="780"/>
@@ -772,7 +772,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="788"/>
         <source>By File &amp;Size</source>
-        <translation>依照檔案大小 (&amp;S)</translation>
+        <translation>依照檔案大小(&amp;S)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="791"/>
@@ -782,7 +782,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="799"/>
         <source>By File &amp;Type</source>
-        <translation>以檔案型態 (&amp;T)</translation>
+        <translation>依照檔案類型(&amp;T)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="802"/>
@@ -830,7 +830,7 @@ in the editing mode.</source>
     <message>
         <location filename="../preferencesdialog.ui" line="33"/>
         <source>Icon theme:</source>
-        <translation>Icon 主題：</translation>
+        <translation>圖示主題：</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="53"/>
@@ -870,7 +870,7 @@ in the editing mode.</source>
     <message>
         <location filename="../preferencesdialog.ui" line="249"/>
         <source>Fit images when navigating</source>
-        <translation>瀏覽時自動調整圖片大小</translation>
+        <translation>導覽時自動符合圖片</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="60"/>
@@ -885,7 +885,7 @@ in the editing mode.</source>
     <message>
         <location filename="../preferencesdialog.ui" line="86"/>
         <source>Use system Trash (and do not prompt)</source>
-        <translation>使用系統的垃圾桶（並且不顯示確認提示）</translation>
+        <translation>使用系統垃圾桶 (並且不作提示)</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="94"/>
@@ -922,8 +922,8 @@ in the editing mode.</source>
         <location filename="../preferencesdialog.ui" line="190"/>
         <source>May work only with images which have valid color spaces.
 Reload current image to see the effect.</source>
-        <translation type="unfinished">May work only with images which have valid color spaces.
-Reload current image to see the effect.</translation>
+        <translation>可能僅適用於具有有效色彩空間的影像圖檔。
+重新載入目前圖檔以查看效果。</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="183"/>
@@ -938,27 +938,27 @@ Reload current image to see the effect.</translation>
     <message>
         <location filename="../preferencesdialog.ui" line="200"/>
         <source>sRGB (supported by most monitors)</source>
-        <translation>sRGB(被大部分的螢幕所支持）</translation>
+        <translation>sRGB (大多數顯示器均有支援）</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="205"/>
         <source>Linear sRGB (linear gamma)</source>
-        <translation type="unfinished"></translation>
+        <translation>線性 sRGB (linear gamma)</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="210"/>
         <source>Adobe RGB</source>
-        <translation type="unfinished"></translation>
+        <translation>Adobe RGB</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="215"/>
         <source>DisplayP3 (wide-gamut screens)</source>
-        <translation type="unfinished"></translation>
+        <translation>DisplayP3 (wide-gamut 螢幕)</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="220"/>
         <source>ProPhotoRgb</source>
-        <translation type="unfinished"></translation>
+        <translation>ProPhotoRgb</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="256"/>
@@ -968,7 +968,7 @@ Reload current image to see the effect.</translation>
     <message>
         <location filename="../preferencesdialog.ui" line="264"/>
         <source>Shortcuts</source>
-        <translation>快捷鍵</translation>
+        <translation>快速鍵</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="283"/>
@@ -978,7 +978,7 @@ Reload current image to see the effect.</translation>
     <message>
         <location filename="../preferencesdialog.ui" line="288"/>
         <source>Shortcut</source>
-        <translation>快捷鍵</translation>
+        <translation>快速鍵</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="296"/>
@@ -988,13 +988,13 @@ Reload current image to see the effect.</translation>
     <message>
         <location filename="../preferencesdialog.ui" line="24"/>
         <source>General</source>
-        <translation>一般</translation>
+        <translation>通則</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../mainwindow.cpp" line="996"/>
+        <location filename="../mainwindow.cpp" line="1041"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
@@ -1004,7 +1004,7 @@ Reload current image to see the effect.</translation>
     <message>
         <location filename="../resizeimagedialog.ui" line="14"/>
         <source>Resize Image</source>
-        <translation>調整圖片尺寸</translation>
+        <translation>變更圖片大小</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="26"/>
@@ -1019,12 +1019,12 @@ Reload current image to see the effect.</translation>
     <message>
         <location filename="../resizeimagedialog.ui" line="40"/>
         <source>Current size:</source>
-        <translation>目前尺寸:</translation>
+        <translation>目前大小：</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="80"/>
         <source>New size:</source>
-        <translation>調整後的尺寸:</translation>
+        <translation>新建大小：</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="93"/>
@@ -1049,12 +1049,12 @@ Reload current image to see the effect.</translation>
     <message>
         <location filename="../screenshotdialog.ui" line="14"/>
         <source>Screenshot</source>
-        <translation>螢幕截圖</translation>
+        <translation>螢幕畫面擷圖</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="27"/>
         <source>Take a screenshot</source>
-        <translation>拍攝螢幕截圖</translation>
+        <translation>取得螢幕畫面擷圖</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="34"/>
